@@ -74,12 +74,18 @@ def GetUniqueItems(list_values):
          list_values.remove(x)
   return result
 
-def CountOccurenceOfValueInString(str, value):
+def CountOccurenceOfValueInString(string,sub_string):
     """
      Returns the count of the number of times a value appears in a string
     """
-    ValueCount = String.Count(Vaue)
-    return ValueCount
+    l=len(sub_string)
+    count=0
+    for i in range(len(string)-len(sub_string)+1):
+        if(string[i:i+len(sub_string)] == sub_string ):      
+            count+=1
+    return count  
+    
+   
 
 def DisposeWebDriver():
         """
@@ -232,4 +238,3 @@ def GetAllDataFromExcelFile(fileName, sheetname) :
              cur_col+=1
          curr_row += 1
          testData.append(dataRow)
-    return dataRow
\ No newline at end of file
